NamedPreferencesPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • NamedPreferencesPlatform
Implementers

Constructors

NamedPreferencesPlatform({String? filename})
Constructs a NamedPreferencesPlatform.

Properties

filename String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() Future<bool>
Removes all keys and values in the store.
getAll() Future<Map<String, Object>>
Returns all key/value pairs persisted in this store.
init({String? filename}) Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String key) Future<bool>
Removes the value associated with the key.
setValue(String valueType, String key, Object value) Future<bool>
Stores the value associated with the key.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited